summary refs log tree commit diff
path: root/nixos/tests
diff options
context:
space:
mode:
authorEelco Dolstra <eelco.dolstra@logicblox.com>2016-06-01 12:51:33 +0200
committerEelco Dolstra <eelco.dolstra@logicblox.com>2016-06-01 12:55:52 +0200
commit9f0e137338a0c8186a104b4af5c6d49d09552784 (patch)
tree1bec27ea5351d4686d48af031e46b4d81c679e32 /nixos/tests
parent587473c574079a72e0c0c57c2ccd106511e5d2f3 (diff)
downloadnixpkgs-9f0e137338a0c8186a104b4af5c6d49d09552784.tar
nixpkgs-9f0e137338a0c8186a104b4af5c6d49d09552784.tar.gz
nixpkgs-9f0e137338a0c8186a104b4af5c6d49d09552784.tar.bz2
nixpkgs-9f0e137338a0c8186a104b4af5c6d49d09552784.tar.lz
nixpkgs-9f0e137338a0c8186a104b4af5c6d49d09552784.tar.xz
nixpkgs-9f0e137338a0c8186a104b4af5c6d49d09552784.tar.zst
nixpkgs-9f0e137338a0c8186a104b4af5c6d49d09552784.zip
Rename boot.loader.gummiboot.enable -> boot.loader.systemd-boot.enable
Diffstat (limited to 'nixos/tests')
-rw-r--r--nixos/tests/installer.nix14
1 files changed, 7 insertions, 7 deletions
diff --git a/nixos/tests/installer.nix b/nixos/tests/installer.nix
index 44c7c738d55..4a30cc18b02 100644
--- a/nixos/tests/installer.nix
+++ b/nixos/tests/installer.nix
@@ -30,8 +30,8 @@ let
           boot.loader.grub.configurationLimit = 100 + ${toString forceGrubReinstallCount};
         ''}
 
-        ${optionalString (bootLoader == "gummiboot") ''
-          boot.loader.gummiboot.enable = true;
+        ${optionalString (bootLoader == "systemd-boot") ''
+          boot.loader.systemd-boot.enable = true;
         ''}
 
         hardware.enableAllFirmware = lib.mkForce false;
@@ -57,7 +57,7 @@ let
         (if system == "x86_64-linux" then "-m 768 " else "-m 512 ") +
         (optionalString (system == "x86_64-linux") "-cpu kvm64 ");
       hdFlags = ''hda => "vm-state-machine/machine.qcow2", hdaInterface => "${iface}", ''
-        + optionalString (bootLoader == "gummiboot") ''bios => "${pkgs.OVMF}/FV/OVMF.fd", '';
+        + optionalString (bootLoader == "systemd-boot") ''bios => "${pkgs.OVMF}/FV/OVMF.fd", '';
     in
     ''
       $machine->start;
@@ -159,7 +159,7 @@ let
 
   makeInstallerTest = name:
     { createPartitions, preBootCommands ? "", extraConfig ? ""
-    , bootLoader ? "grub" # either "grub" or "gummiboot"
+    , bootLoader ? "grub" # either "grub" or "systemd-boot"
     , grubVersion ? 2, grubDevice ? "/dev/vda", grubIdentifier ? "uuid"
     , enableOCR ? false, meta ? {}
     }:
@@ -195,7 +195,7 @@ let
             virtualisation.qemu.diskInterface =
               if grubVersion == 1 then "scsi" else "virtio";
 
-            boot.loader.gummiboot.enable = mkIf (bootLoader == "gummiboot") true;
+            boot.loader.systemd-boot.enable = mkIf (bootLoader == "systemd-boot") true;
 
             hardware.enableAllFirmware = mkForce false;
 
@@ -249,7 +249,7 @@ in {
         '';
     };
 
   # Simple GPT/UEFI configuration using Gummiboot with 3 partitions: ESP, swap & root filesystem
   simpleUefiGummiboot = makeInstallerTest "simpleUefiGummiboot"
     { createPartitions =
         ''
@@ -269,7 +269,7 @@ in {
               "mount LABEL=BOOT /mnt/boot",
           );
         '';
-        bootLoader = "gummiboot";
+        bootLoader = "systemd-boot";
     };
 
   # Same as the previous, but now with a separate /boot partition.
@@ -249,7 +249,7 @@ in {
     };
 
-  # Simple GPT/UEFI configuration using Gummiboot with 3 partitions: ESP, swap & root filesystem
+  # Simple GPT/UEFI configuration using systemd-boot with 3 partitions: ESP, swap & root filesystem
   simpleUefiGummiboot = makeInstallerTest "simpleUefiGummiboot"
     { createPartitions =